Index — PBI_dashboard_creator 1.0.62 documentation

# Index

A | C | M | P | U

## A

add_background_img() (in module PBI_dashboard_creator.add_background_image) add_button() (in module PBI_dashboard_creator.add_button) add_chart() (in module PBI_dashboard_creator.create_new_chart) add_csv() (in module PBI_dashboard_creator.add_local_csv) | add_csv_from_blob() (in module PBI_dashboard_creator.add_ADLS_csv) add_new_page() (in module PBI_dashboard_creator.create_new_page) add_shape_map() (in module PBI_dashboard_creator.add_shape_map) add_text_box() (in module PBI_dashboard_creator.add_text_box) add_tmdl_dataset() (in module PBI_dashboard_creator.add_tmdl)

## C

create_date_hr() (in module PBI_dashboard_creator.create_date_hrcy) | create_new_dashboard() (in module PBI_dashboard_creator.create_blank_dashboard) create_tmdl() (in module PBI_dashboard_creator.create_tmdl)

## M

module PBI_dashboard_creator, [1] PBI_dashboard_creator.add_ADLS_csv PBI_dashboard_creator.add_background_image PBI_dashboard_creator.add_button PBI_dashboard_creator.add_local_csv PBI_dashboard_creator.add_shape_map PBI_dashboard_creator.add_text_box PBI_dashboard_creator.add_tmdl PBI_dashboard_creator.create_blank_dashboard PBI_dashboard_creator.create_date_hrcy PBI_dashboard_creator.create_new_chart PBI_dashboard_creator.create_new_page PBI_dashboard_creator.create_tmdl PBI_dashboard_creator.update_diagramLayout PBI_dashboard_creator.update_model_file

## P

PBI_dashboard_creator module, [1] PBI_dashboard_creator.add_ADLS_csv module PBI_dashboard_creator.add_background_image module PBI_dashboard_creator.add_button module PBI_dashboard_creator.add_local_csv module PBI_dashboard_creator.add_shape_map module PBI_dashboard_creator.add_text_box module PBI_dashboard_creator.add_tmdl module | PBI_dashboard_creator.create_blank_dashboard module PBI_dashboard_creator.create_date_hrcy module PBI_dashboard_creator.create_new_chart module PBI_dashboard_creator.create_new_page module PBI_dashboard_creator.create_tmdl module PBI_dashboard_creator.update_diagramLayout module PBI_dashboard_creator.update_model_file module

## U

update_diagramLayout() (in module PBI_dashboard_creator.update_diagramLayout) | update_model_file() (in module PBI_dashboard_creator.update_model_file)